@@ -3,7 +3,7 @@ import repository from './repository'
 const resource = 'alarms'
 
 export default {
-  getAll () {
-    return repository.get(`${resource}/`)
+  getAll (params) {
+    return repository.get(`${resource}/`, { params })
   }
 }
