@@ -136,6 +136,15 @@ const routes = [
       allowedRoles: ['DomainAdmins', 'SuperAdmins']
     }
   },
+  {
+    path: '/information',
+    name: 'Information',
+    component: () => import('../views/admin/Information.vue'),
+    meta: {
+      requiresAuth: true,
+      allowedRoles: ['SuperAdmins']
+    }
+  },
   {
     path: '/user/api',
     name: 'APISetup',
@@ -172,6 +181,21 @@ const routes = [
       requiresAuth: true,
       layout: 'user'
     }
+  },
+  {
+    path: '/password_recovery',
+    name: 'PasswordRecoveryForm',
+    component: () => import('../views/user/PasswordRecoveryForm.vue')
+  },
+  {
+    path: '/password_recovery/confirm/:id?/:token?/',
+    name: 'PasswordRecoveryChangeForm',
+    component: () => import('../views/user/PasswordRecoveryChangeForm.vue')
+  },
+  {
+    path: '/password_recovery/sms_confirm',
+    name: 'PasswordRecoverySms',
+    component: () => import('../views/user/PasswordRecoverySmsTotpForm.vue')
   }
 ]
 
