@@ -7,7 +7,7 @@ from django.contrib.contenttypes.models import ContentType
 from django_filters import rest_framework as dj_filters
 from drf_spectacular.utils import extend_schema, extend_schema_view
 from rest_framework import (
-    filters, mixins, parsers, permissions, response, status, viewsets
+    filters, mixins, parsers, pagination, permissions, response, status, viewsets
 )
 from rest_framework.decorators import action
 from rest_framework.exceptions import PermissionDenied
@@ -16,6 +16,7 @@ from modoboa.admin.api.v1 import viewsets as v1_viewsets
 from modoboa.core import models as core_models
 from modoboa.lib import renderers as lib_renderers
 from modoboa.lib import viewsets as lib_viewsets
+from modoboa.lib.throttle import GetThrottleViewsetMixin
 
 from ... import lib
 from ... import models
@@ -40,7 +41,7 @@ from . import serializers
         summary="Delete a particular domain"
     ),
 )
-class DomainViewSet(lib_viewsets.RevisionModelMixin,
+class DomainViewSet(GetThrottleViewsetMixin, lib_viewsets.RevisionModelMixin,
                     mixins.ListModelMixin,
                     mixins.RetrieveModelMixin,
                     mixins.CreateModelMixin,
@@ -160,6 +161,7 @@ class AccountViewSet(v1_viewsets.AccountViewSet):
     filter_backends = (filters.SearchFilter, dj_filters.DjangoFilterBackend)
     filterset_class = AccountFilterSet
 
+
     def get_serializer_class(self):
         if self.action in ["create", "validate", "update", "partial_update"]:
             return serializers.WritableAccountSerializer
@@ -208,7 +210,7 @@ class AccountViewSet(v1_viewsets.AccountViewSet):
         return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
-class IdentityViewSet(viewsets.ViewSet):
+class IdentityViewSet(GetThrottleViewsetMixin, viewsets.ViewSet):
     """Viewset for identities."""
 
     permission_classes = (permissions.IsAuthenticated, )
@@ -270,7 +272,7 @@ class AliasViewSet(v1_viewsets.AliasViewSet):
         })
 
 
-class UserAccountViewSet(viewsets.ViewSet):
+class UserAccountViewSet(GetThrottleViewsetMixin, viewsets.ViewSet):
     """Viewset for current user operations."""
 
     @action(methods=["get", "post"], detail=False)
@@ -323,16 +325,20 @@ class UserAccountViewSet(viewsets.ViewSet):
         return response.Response(serializer.validated_data)
 
 
-class AlarmViewSet(viewsets.ReadOnlyModelViewSet):
+class AlarmViewSet(GetThrottleViewsetMixin, viewsets.ReadOnlyModelViewSet):
     """Viewset for Alarm."""
 
+    filter_backends = (filters.OrderingFilter, filters.SearchFilter, )
+    ordering_fields = ["created", "status", "title"]
+    pagination_class = pagination.PageNumberPagination
     permission_classes = (
         permissions.IsAuthenticated,
     )
+    search_fields = ["domain__name", "title"]
     serializer_class = serializers.AlarmSerializer
 
     def get_queryset(self):
-        return models.Alarm.objects.filter(
+        return models.Alarm.objects.select_related("domain").filter(
             domain__in=models.Domain.objects.get_for_admin(
                 self.request.user)
-        )
+        ).order_by("-created")
