@@ -3,19 +3,20 @@
 import hashlib
 import random
 
-from reversion import revisions as reversion
-
+from django.core.exceptions import ValidationError
 from django.db import models
 from django.urls import reverse
 from django.utils.encoding import (
-    force_bytes, force_str, python_2_unicode_compatible, smart_text
+    force_bytes, force_str, smart_text
 )
 from django.utils.translation import ugettext as _, ugettext_lazy
 
+from reversion import revisions as reversion
+
 from modoboa.core import signals as core_signals
 from modoboa.lib.email_utils import split_mailbox
 from modoboa.lib.exceptions import (
-    BadRequest, Conflict, NotFound, PermDeniedException
+    BadRequest, Conflict, NotFound, ModoboaException
 )
 from .. import signals
 from .base import AdminObject
@@ -23,9 +24,47 @@ from .domain import Domain
 from .mailbox import Mailbox
 
 
-@python_2_unicode_compatible
-class Alias(AdminObject):
+def validate_alias_address(address, creator, internal=False, instance=None):
+    """Check if the given alias address can be created by creator."""
+    local_part, domain = split_mailbox(address)
+    domain = Domain.objects.filter(name=domain).first()
+    if domain is None:
+        raise ValidationError(_("Domain not found."))
+    if not creator.can_access(domain):
+        raise ValidationError(_("Permission denied."))
+    if not instance or instance.address != address:
+        if Alias.objects.filter(address=address, internal=internal).exists():
+            raise ValidationError(_("An alias with this name already exists."))
+    if instance is None:
+        try:
+            # Check creator limits
+            core_signals.can_create_object.send(
+                sender="validate_alias_address", context=creator, klass=Alias)
+            # Check domain limits
+            core_signals.can_create_object.send(
+                sender="validate_alias_address", context=domain,
+                object_type="mailbox_aliases")
+        except ModoboaException as inst:
+            raise ValidationError(str(inst))
+    return local_part, domain
 
+
+class AliasManager(models.Manager):
+    """Custom manager for Alias."""
+
+    def create(self, *args, **kwargs):
+        """Custom create method."""
+        creator = kwargs.pop("creator", None)
+        recipients = kwargs.pop("recipients", None)
+        alias = super().create(*args, **kwargs)
+        if creator:
+            alias.post_create(creator)
+        if recipients:
+            alias.set_recipients(recipients)
+        return alias
+
+
+class Alias(AdminObject):
     """Mailbox alias."""
 
     address = models.CharField(
@@ -47,13 +86,15 @@ class Alias(AdminObject):
         ugettext_lazy("Expire at"), blank=True, null=True)
     _objectname = "MailboxAlias"
 
+    objects = AliasManager()
+
     class Meta:
         ordering = ["address"]
         unique_together = (("address", "internal"), )
         app_label = "admin"
 
     def __str__(self):
-        return smart_text(self.address)
+        return self.address
 
     @classmethod
     def generate_random_address(cls):
@@ -79,7 +120,6 @@ class Alias(AdminObject):
 
     @property
     def type(self):
-        """FIXME: deprecated."""
         return "alias"
 
     @property
@@ -97,8 +137,8 @@ class Alias(AdminObject):
             for admin in self.domain.admins:
                 grant_access_to_object(admin, self)
 
-    def set_recipients(self, address_list):
-        """Set recipients for this alias.
+    def add_recipients(self, address_list):
+        """Add recipients for this alias.
 
         Special recipients:
         * local mailbox + extension: r_mailbox will be set to local mailbox
@@ -147,6 +187,11 @@ class Alias(AdminObject):
                     kwargs["r_mailbox"] = rcpt
             AliasRecipient(**kwargs).save()
 
+    def set_recipients(self, address_list):
+        """Set recipients for this alias."""
+
+        self.add_recipients(address_list)
+
         # Remove old recipients
         self.aliasrecipient_set.exclude(
             address__in=address_list).delete()
@@ -167,38 +212,27 @@ class Alias(AdminObject):
     def from_csv(self, user, row, expected_elements=5):
         """Create a new alias from a CSV file entry."""
         if len(row) < expected_elements:
-            raise BadRequest(_("Invalid line: %s" % row))
-        address = row[1].strip().lower()
-        localpart, domname = split_mailbox(address)
-        try:
-            domain = Domain.objects.get(name=domname)
-        except Domain.DoesNotExist:
-            raise BadRequest(_("Domain '%s' does not exist" % domname))
-        if not user.can_access(domain):
-            raise PermDeniedException
-        core_signals.can_create_object.send(
-            sender="import", context=user, klass=Alias)
-        core_signals.can_create_object.send(
-            sender="import", context=domain, object_type="mailbox_aliases")
-        if Alias.objects.filter(address=address, internal=False).exists():
-            raise Conflict
-        self.address = address
-        self.domain = domain
+            raise BadRequest(_("Invalid line: {}").format(row))
+        self.address = row[1].strip().lower()
+        local_part, self.domain = validate_alias_address(self.address, user)
         self.enabled = (row[2].strip().lower() in ["true", "1", "yes", "y"])
         self.save()
         self.set_recipients([raddress.strip() for raddress in row[3:]])
         self.post_create(user)
 
-    def to_csv(self, csvwriter):
+    def to_csv_row(self):
+        """Return a row to include in a CSV file."""
         row = ["alias", force_str(self.address), self.enabled]
         row += self.recipients
-        csvwriter.writerow(row)
+        return row
+
+    def to_csv(self, csvwriter):
+        csvwriter.writerow(self.to_csv_row())
 
 
 reversion.register(Alias)
 
 
-@python_2_unicode_compatible
 class AliasRecipient(models.Model):
 
     """An alias recipient."""
