@@ -152,7 +152,7 @@ Domains.prototype = {
             : gettext("This operation will remove all data associated to this domain, excepting accounts.");
 
         $("a[name=deldomain]").confirm({
-            question: function() { return this.$element.attr('title'); },
+            question: function() { return htmlEncode(this.$element.attr('title')); },
             method: "POST",
             warning: warnmsg,
             checkboxes: deloptions,
@@ -172,9 +172,12 @@ Domains.prototype = {
         if (this.navobj.getbaseurl() === "list") {
             args.objtype = "domain";
             this.options.eor_message = gettext("No more domain to show");
-        } else {
+        } else if (this.navobj.getbaseurl() === "quotas") {
             args.objtype = "quota";
             this.options.eor_message = gettext("No more quota to show");
+        } else {
+            args.objtype = "log";
+            this.options.eor_message = gettext("No more log to show");
         }
         return args;
     },
@@ -292,7 +295,7 @@ Domains.prototype = {
 
     optionsform_prefill: function() {
         var $span = $("#id_dom_admin_username").next("span");
-        $span.html("@" + $("#id_name").val());
+        $span.html("@" + htmlEncode($("#id_name").val()));
     },
 
     domadminsform_init: function() {
@@ -405,7 +408,7 @@ Identities.prototype = {
         }
 
         $("a[name=delaccount]").confirm({
-            question: function() { return this.$element.attr('title'); },
+            question: function() { return htmlEncode(this.$element.attr('title')); },
             method: "POST",
             checkboxes: deloptions,
             success_cb: $.proxy(this.reload_listing, this)
