@@ -1,6 +1,7 @@
 """Core urls."""
 
 from django.urls import path
+from django.views.generic.base import TemplateView
 
 from . import views
 
@@ -12,6 +13,9 @@ urlpatterns = [
 
     path('accounts/login/', views.dologin, name="login"),
     path('accounts/logout/', views.dologout, name="logout"),
+    path('accounts/2fa_verify/',
+         views.TwoFactorCodeVerifyView.as_view(),
+         name='2fa_verify'),
 
     path('core/', views.viewsettings, name="index"),
     path('core/parameters/', views.parameters, name="parameters"),
@@ -27,4 +31,6 @@ urlpatterns = [
          name="user_preferences"),
     path('user/profile/', views.profile, name="user_profile"),
     path('user/api/', views.api_access, name="user_api_access"),
+    path('user/security/', views.security, name="user_security"),
+    path('robots.txt', TemplateView.as_view(template_name="core/robots.txt", content_type="text/plain")),
 ]
