@@ -4,11 +4,13 @@ import logging
 
 import oath
 
-from django.http import HttpResponse, HttpResponseRedirect, Http404
+from django.http import (
+    HttpResponse, HttpResponseRedirect, Http404, JsonResponse)
 from django.template.loader import render_to_string
 from django.urls import reverse
 from django.utils import translation
 from django.utils.encoding import force_bytes
+from django.utils.html import escape
 from django.utils.http import urlsafe_base64_encode
 from django.utils.translation import ugettext as _
 from django.views import generic
@@ -17,15 +19,15 @@ from django.views.decorators.cache import never_cache
 from django.contrib.auth import (
     authenticate, login, logout, views as auth_views
 )
+from django.contrib.auth.mixins import LoginRequiredMixin
 from django.contrib.auth.tokens import default_token_generator
 
-from braces.views import (
-    JSONResponseMixin, LoginRequiredMixin, UserFormKwargsMixin)
 import django_otp
 
 from modoboa.core import forms
 from modoboa.core.password_hashers import get_password_hasher
 from modoboa.lib import cryptutils
+from modoboa.lib.views import UserFormKwargsMixin
 from modoboa.parameters import tools as param_tools
 
 from .. import models
@@ -46,8 +48,12 @@ def dologin(request):
             user = authenticate(username=form.cleaned_data["username"],
                                 password=form.cleaned_data["password"])
             if user and user.is_active:
-                if param_tools.get_global_parameter("update_scheme",
-                                                    raise_exception=False):
+                condition = (
+                    user.is_local and
+                    param_tools.get_global_parameter(
+                        "update_scheme", raise_exception=False)
+                )
+                if condition:
                     # check if password scheme is correct
                     scheme = param_tools.get_global_parameter(
                         "password_scheme", raise_exception=False)
@@ -93,7 +99,7 @@ def dologin(request):
             logger.warning(
                 "Failed connection attempt from '%(addr)s' as user '%(user)s'"
                 % {"addr": request.META["REMOTE_ADDR"],
-                   "user": form.cleaned_data["username"]}
+                   "user": escape(form.cleaned_data["username"])}
             )
 
         nextlocation = request.POST.get("next", "")
@@ -204,7 +210,7 @@ class VerifySMSCodeView(generic.FormView):
         return HttpResponseRedirect(url)
 
 
-class ResendSMSCodeView(JSONResponseMixin, generic.View):
+class ResendSMSCodeView(generic.View):
     """A view to resend validation code."""
 
     def get(self, request, *args, **kwargs):
@@ -230,7 +236,7 @@ class ResendSMSCodeView(JSONResponseMixin, generic.View):
         if not backend.send(text, [user.phone_number]):
             raise Http404
         self.request.session["totp_secret"] = secret
-        return self.render_json_response({"status": "ok"})
+        return JsonResponse({"status": "ok"})
 
 
 class TwoFactorCodeVerifyView(LoginRequiredMixin,
