@@ -147,6 +147,7 @@ TEMPLATES = [
                 'django.template.context_processors.tz',
                 'django.contrib.messages.context_processors.messages',
                 'modoboa.core.context_processors.top_notifications',
+                'modoboa.core.context_processors.new_admin_url'
             ],
             'debug': DEBUG,
         },
@@ -185,6 +186,15 @@ MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
 # Rest framework settings
 
 REST_FRAMEWORK = {
+    'DEFAULT_THROTTLE_RATES': {
+        'user': '200/minute',
+        'ddos': '10/second',
+        'ddos_lesser': '200/minute',
+        'login': '10/minute',
+        'password_recovery_request': '11/hour',
+        'password_recovery_totp_check': '25/hour',
+        'password_recovery_apply': '25/hour'
+    },
     'DEFAULT_AUTHENTICATION_CLASSES': (
         'modoboa.core.drf_authentication.JWTAuthenticationWith2FA',
         'rest_framework.authentication.TokenAuthentication',
@@ -194,6 +204,9 @@ REST_FRAMEWORK = {
     'DEFAULT_VERSIONING_CLASS': 'rest_framework.versioning.NamespaceVersioning',
 }
 
+# Uncomment if you need a custom sub url for new_admin interface
+# NEW_ADMIN_URL = 'new_admin'
+
 SPECTACULAR_SETTINGS = {
     'SCHEMA_PATH_PREFIX': r'/api/v[0-9]',
     'TITLE': 'Modoboa API',
@@ -208,6 +221,8 @@ SPECTACULAR_SETTINGS = {
 
 MODOBOA_API_URL = 'https://api.modoboa.org/1/'
 
+PID_FILE_STORAGE_PATH = '/tmp'
+
 # REDIS
 
 REDIS_HOST = 'localhost'
